Use different functions to emit the string and symbol tables.


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@73895 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/ELFWriter.cpp b/lib/CodeGen/ELFWriter.cpp
index 281cf2f..acdf3d5d 100644
--- a/lib/CodeGen/ELFWriter.cpp
+++ b/lib/CodeGen/ELFWriter.cpp
@@ -386,6 +386,9 @@
   if (TAI->getNonexecutableStackDirective())
     getNonExecStackSection();
 
+  // Emit string table
+  EmitStringTable();
+
   // Emit the symbol table now, if non-empty.
   EmitSymbolTable();
 
@@ -518,12 +521,10 @@
   }
 }
 
-/// EmitSymbolTable - If the current symbol table is non-empty, emit the string
-/// table for it and then the symbol table itself.
-void ELFWriter::EmitSymbolTable() {
+/// EmitStringTable - If the current symbol table is non-empty, emit the string
+/// table for it
+void ELFWriter::EmitStringTable() {
   if (!SymbolList.size()) return;  // Empty symbol table.
-
-  unsigned FirstNonLocalSymbol = 1;
   ELFSection &StrTab = getStringTableSection();
 
   // Set the zero'th symbol to a null byte, as required.
@@ -550,12 +551,20 @@
   }
   assert(Index == StrTab.size());
   StrTab.Size = Index;
+}
 
+/// EmitSymbolTable - Emit the symbol table itself.
+void ELFWriter::EmitSymbolTable() {
+  if (!SymbolList.size()) return;  // Empty symbol table.
+
+  unsigned FirstNonLocalSymbol = 1;
   // Now that we have emitted the string table and know the offset into the
   // string table of each symbol, emit the symbol table itself.
   ELFSection &SymTab = getSymbolTableSection();
   SymTab.Align = TEW->getPrefELFAlignment();
-  SymTab.Link  = StrTab.SectionIdx;      // Section Index of .strtab.
+
+  // Section Index of .strtab.
+  SymTab.Link = getStringTableSection().SectionIdx;
 
   // Size of each symtab entry.
   SymTab.EntSize = TEW->getSymTabEntrySize();
@@ -566,7 +575,7 @@
 
   // Emit all the symbols to the symbol table. Skip the null
   // symbol, cause it's emitted already
-  Index = 1;
+  unsigned Index = 1;
   for (std::list<ELFSym>::iterator I = SymbolList.begin(),
        E = SymbolList.end(); I != E; ++I, ++Index) {
     // Keep track of the first non-local symbol